/*
 * Copyright (C) 2006-2007 Imendio AB
 * Copyright (C) 2007-2008 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * Authors: Martyn Russell <martyn@imendio.com>
 *          Xavier Claessens <xclaesse@gmail.com>
 */

#ifndef __EMPATHY_GEOMETRY_H__
#define __EMPATHY_GEOMETRY_H__

#include <glib.h>
#include <gtk/gtk.h>

G_BEGIN_DECLS

void empathy_geometry_save (GtkWindow *window,
    const gchar *name);

void empathy_geometry_load (GtkWindow *window,
    const gchar *name);

void empathy_geometry_bind (GtkWindow *window,
    const gchar *name);

void empathy_geometry_unbind (GtkWindow *window);

G_END_DECLS

#endif /* __EMPATHY_GEOMETRY_H__ */
